pub struct SeedersTemplate {
pub content: String,
pub sections: Vec<DocSection>,
pub current_page: String,
}Fields
content: Stringsections: Vec<DocSection>current_page: StringTrait Implementations
Sourceimpl Default for SeedersTemplate
impl Default for SeedersTemplate
Sourcefn default() -> SeedersTemplate
fn default() -> SeedersTemplate
Returns the “default value” for a type. Read more
Sourceimpl Display for SeedersTemplate
impl Display for SeedersTemplate
Sourceimpl IntoResponse for SeedersTemplate
impl IntoResponse for SeedersTemplate
Sourcefn into_response(self) -> Response
fn into_response(self) -> Response
Create a response.
Sourceimpl Template for SeedersTemplate
impl Template for SeedersTemplate
Sourceconst SIZE_HINT: usize = 18_231usize
const SIZE_HINT: usize = 18_231usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourceconst MIME_TYPE: &'static str = "text/html; charset=utf-8"
const MIME_TYPE: &'static str = "text/html; charset=utf-8"
The MIME type (Content-Type) of the data that gets rendered by this Template
Sourcefn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
fn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
Renders the template to the given
writer fmt bufferAuto Trait Implementations
impl Freeze for SeedersTemplate
impl RefUnwindSafe for SeedersTemplate
impl Send for SeedersTemplate
impl Sync for SeedersTemplate
impl Unpin for SeedersTemplate
impl UnwindSafe for SeedersTemplate